@@ -13,23 +13,23 @@ test_that("YahooInPlaySource",{
 	lengthcorp <- length(testcorp)
 	# Check Corpus object
 	expect_that(length(testcorp) >= minlengthcorp, is_true())
-	expect_that(class(testcorp), equals(c("WebCorpus","VCorpus","Corpus","list")))
+	expect_that(class(testcorp), equals(c("WebCorpus","VCorpus","Corpus")))
 	
 	# Check Content
 	#expect_that(all(sapply(testcorp, nchar) > 0), is_true())
-	contentratio <- length(which(sapply(testcorp, nchar) > 0)) / length(testcorp)
+	contentratio <- length(which(sapply(testcorp, nchar)[1,] > 0)) / length(testcorp)
 	expect_that(contentratio > 0.5, is_true())
 	
 	# Check Meta Data
-	datetimestamp <- lapply(testcorp, function(x) meta(x, "DateTimeStamp"))
+	datetimestamp <- lapply(testcorp, function(x) meta(x, "datetimestamp"))
 	#FIXME: Date should be fixed
 	expect_that(all(sapply(datetimestamp, function(x) class(x)[1] == "character")), is_true())
 	
-	heading <- lapply(testcorp, function(x) meta(x, "Heading"))
+	heading <- lapply(testcorp, function(x) meta(x, "heading")[1])
 	expect_that(all(sapply(heading, function(x) class(x)[1] == "character")), is_true())
 	expect_that(all(sapply(heading, nchar) > 0), is_true())
 	
-	id <- lapply(testcorp, function(x) meta(x, "ID"))
+	id <- lapply(testcorp, function(x) meta(x, "id")[1])
 	expect_that(all(sapply(id, function(x) class(x)[1] == "character")), is_true())
 	expect_that(all(sapply(id, nchar) > 0), is_true())
 	
